@@ -405,3 +405,16 @@ JOIN b
   'eeeeeeeeeeeeeeeeeeeee'
 );
 
+/* COMMENT */
+INSERT FIRST WHEN salary > 4000 THEN INTO emp2
+             WHEN salary > 5000 THEN INTO emp3
+             WHEN salary > 6000 THEN INTO emp4
+SELECT salary FROM employees;
+/* COMMENT */
+INSERT FIRST
+  WHEN salary > 4000 THEN INTO emp2
+  WHEN salary > 5000 THEN INTO emp3
+  WHEN salary > 6000 THEN INTO emp4
+SELECT
+  salary
+FROM employees;
